==> st_common_data-0.1.3.tar.gz: st_common_data-0.1.3/st_common_data/nyse_holidays.py <==
NYSE_HOLIDAYS = [
    # ---------- 2022 -------------------
    {
        'date': '17.01.2022',
        'name': 'Martin Luther King Jr. Day',
        'status': 'Closed',
    },
    {
        'date': '21.02.2022',
        'name': 'Washington\'s Birthday',
        'status': 'Closed',
    },
    {
        'date': '15.04.2022',
        'name': 'Good Friday',
        'status': 'Closed',
    },
    {
        'date': '30.05.2022',
        'name': 'Memorial Day',
        'status': 'Closed',
    },
    {
        'date': '20.06.2022',
        'name': 'Juneteenth N.I. Day',
        'status': 'Closed',
    },
    {
        'date': '04.07.2022',
        'name': 'Independence Day',
        'status': 'Closed',
    },
    {
        'date': '05.09.2022',
        'name': 'Labor Day',
        'status': 'Closed',
    },
    {
        'date': '24.11.2022',
        'name': 'Thanksgiving Day',
        'status': 'Closed',
    },
    {
        'date': '25.11.2022',
        'name': 'Thanksgiving Day',
        'status': '9:30 AM - 1:00 PM',
    },
    {
        'date': '26.12.2022',
        'name': 'Christmas Day',
        'status': 'Closed',
    },
    # ---------- 2023 -------------------
    {
        'date': '02.01.2023',
        'name': 'New Years Day',
        'status': 'Closed',
    },
    {
        'date': '16.01.2023',
        'name': 'Martin Luther King Jr. Day',
        'status': 'Closed',
    },
    {
        'date': '20.02.2023',
        'name': 'Washington\'s Birthday',
        'status': 'Closed',
    },
    {
        'date': '07.04.2023',
        'name': 'Good Friday',
        'status': 'Closed',
    },
    {
        'date': '29.05.2023',
        'name': 'Memorial Day',
        'status': 'Closed',
    },
    {
        'date': '19.06.2023',
        'name': 'Juneteenth N.I. Day',
        'status': 'Closed',
    },
    {
        'date': '04.07.2023',
        'name': 'Independence Day',
        'status': 'Closed',
    },
    {
        'date': '04.09.2023',
        'name': 'Labor Day',
        'status': 'Closed',
    },
    {
        'date': '23.11.2023',
        'name': 'Thanksgiving Day',
        'status': 'Closed',
    },
    {
        'date': '24.11.2023',
        'name': 'Thanksgiving Day',
        'status': '9:30 AM - 1:00 PM',
    },
    {
        'date': '25.12.2023',
        'name': 'Christmas Day',
        'status': 'Closed',
    },
]

==> st_common_data-0.1.13.tar.gz: st_common_data-0.1.13/st_common_data/nyse_holidays.py <==
NYSE_HOLIDAYS = [
{
        'date': '07.09.2020',
        'name': 'Labor Day',
        'status': 'Closed',
    },
    {
        'date': '26.11.2020',
        'name': 'Thanksgiving Day',
        'status': 'Closed',
    },
    {
        'date': '27.11.2020',
        'name': 'Thanksgiving Day',
        'status': '9:30 AM - 1:00 PM',
    },
    {
        'date': '24.12.2020',
        'name': 'Christmas',
        'status': '9:30 AM - 1:00 PM',
    },
    {
        'date': '25.12.2020',
        'name': 'Christmas',
        'status': 'Closed',
    },
    # ---------- 2021 --------------------
    {
        'date': '01.01.2021',
        'name': 'New Year\'s Day',
        'status': 'Closed',
    },
    {
        'date': '18.01.2021',
        'name': 'Martin Luther King Jr. Day',
        'status': 'Closed',
    },
    {
        'date': '15.02.2021',
        'name': 'Washington\'s Birthday',
        'status': 'Closed',
    },
    {
        'date': '02.04.2021',
        'name': 'Good Friday',
        'status': 'Closed',
    },
    {
        'date': '31.05.2021',
        'name': 'Memorial Day',
        'status': 'Closed',
    },
    {
        'date': '05.07.2021',
        'name': 'Independence Day',
        'status': 'Closed',
    },
    {
        'date': '06.09.2021',
        'name': 'Labor Day',
        'status': 'Closed',
    },
    {
        'date': '25.11.2021',
        'name': 'Thanksgiving Day',
        'status': 'Closed',
    },
    {
        'date': '26.11.2021',
        'name': 'Thanksgiving Day',
        'status': '9:30 AM - 1:00 PM',
    },
    {
        'date': '24.12.2021',
        'name': 'Christmas',
        'status': 'Closed',
    },
    # ---------- 2022 -------------------
    {
        'date': '17.01.2022',
        'name': 'Martin Luther King Jr. Day',
        'status': 'Closed',
    },
    {
        'date': '21.02.2022',
        'name': 'Washington\'s Birthday',
        'status': 'Closed',
    },
    {
        'date': '15.04.2022',
        'name': 'Good Friday',
        'status': 'Closed',
    },
    {
        'date': '30.05.2022',
        'name': 'Memorial Day',
        'status': 'Closed',
    },
    {
        'date': '20.06.2022',
        'name': 'Juneteenth N.I. Day',
        'status': 'Closed',
    },
    {
        'date': '04.07.2022',
        'name': 'Independence Day',
        'status': 'Closed',
    },
    {
        'date': '05.09.2022',
        'name': 'Labor Day',
        'status': 'Closed',
    },
    {
        'date': '24.11.2022',
        'name': 'Thanksgiving Day',
        'status': 'Closed',
    },
    {
        'date': '25.11.2022',
        'name': 'Thanksgiving Day',
        'status': '9:30 AM - 1:00 PM',
    },
    {
        'date': '26.12.2022',
        'name': 'Christmas Day',
        'status': 'Closed',
    },
    # ---------- 2023 -------------------
    {
        'date': '02.01.2023',
        'name': 'New Years Day',
        'status': 'Closed',
    },
    {
        'date': '16.01.2023',
        'name': 'Martin Luther King Jr. Day',
        'status': 'Closed',
    },
    {
        'date': '20.02.2023',
        'name': 'Washington\'s Birthday',
        'status': 'Closed',
    },
    {
        'date': '07.04.2023',
        'name': 'Good Friday',
        'status': 'Closed',
    },
    {
        'date': '29.05.2023',
        'name': 'Memorial Day',
        'status': 'Closed',
    },
    {
        'date': '19.06.2023',
        'name': 'Juneteenth N.I. Day',
        'status': 'Closed',
    },
    {
        'date': '04.07.2023',
        'name': 'Independence Day',
        'status': 'Closed',
    },
    {
        'date': '04.09.2023',
        'name': 'Labor Day',
        'status': 'Closed',
    },
    {
        'date': '23.11.2023',
        'name': 'Thanksgiving Day',
        'status': 'Closed',
    },
    {
        'date': '24.11.2023',
        'name': 'Thanksgiving Day',
        'status': '9:30 AM - 1:00 PM',
    },
    {
        'date': '25.12.2023',
        'name': 'Christmas Day',
        'status': 'Closed',
    },
]
